Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(145)

Unified Diff: third_party/WebKit/Source/core/workers/WorkerObjectProxy.h

Issue 1888703002: Worker: Rename worker components to clarify what they work for (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: add missing files Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/workers/WorkerObjectProxy.h
diff --git a/third_party/WebKit/Source/core/workers/WorkerObjectProxy.h b/third_party/WebKit/Source/core/workers/WorkerObjectProxy.h
index eb888d84bfe0423bca8dcee514d83ec09597e954..ae4445ba5b7b2f6205dbca2c476aa8a51e8339f7 100644
--- a/third_party/WebKit/Source/core/workers/WorkerObjectProxy.h
+++ b/third_party/WebKit/Source/core/workers/WorkerObjectProxy.h
@@ -43,19 +43,19 @@ namespace blink {
class ConsoleMessage;
class ExecutionContext;
class ExecutionContextTask;
-class WorkerMessagingProxy;
+class InProcessWorkerMessagingProxy;
// A proxy to talk to the worker object. This object is created on the
// worker object thread (i.e. usually the main thread), passed on to
// the worker thread, and used just to proxy messages to the
// WorkerMessagingProxy on the worker object thread.
//
// Used only by in-process workers (DedicatedWorker and CompositorWorker.)
class CORE_EXPORT WorkerObjectProxy : public WorkerReportingProxy {
USING_FAST_MALLOC(WorkerObjectProxy);
WTF_MAKE_NONCOPYABLE(WorkerObjectProxy);
public:
- static PassOwnPtr<WorkerObjectProxy> create(WorkerMessagingProxy*);
+ static PassOwnPtr<WorkerObjectProxy> create(InProcessWorkerMessagingProxy*);
~WorkerObjectProxy() override { }
void postMessageToWorkerObject(PassRefPtr<SerializedScriptValue>, PassOwnPtr<MessagePortChannelArray>);
@@ -75,12 +75,12 @@ public:
void willDestroyWorkerGlobalScope() override { }
protected:
- WorkerObjectProxy(WorkerMessagingProxy*);
+ WorkerObjectProxy(InProcessWorkerMessagingProxy*);
virtual ExecutionContext* getExecutionContext();
private:
// This object always outlives this proxy.
- WorkerMessagingProxy* m_messagingProxy;
+ InProcessWorkerMessagingProxy* m_messagingProxy;
};
} // namespace blink
@@ -43,19 +43,19 @@ namespace blink {
// worker object thread (i.e. usually the main thread), passed on to
// the worker thread, and used just to proxy messages to the
-// WorkerMessagingProxy on the worker object thread.
+// InProcessWorkerMessagingProxy on the worker object thread.
//
// Used only by in-process workers (DedicatedWorker and CompositorWorker.)

Powered by Google App Engine
This is Rietveld 408576698